(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0c14f9"],{4601:function(t,a,e){"use strict";e.r(a);var s=function(){var t=this,a=t.$createElement,e=t._self._c||a;return e("div",{staticClass:"dashboard-page"},t._l(t.sidebarInfo(),(function(a){return e("el-card",{key:a.meta.key,staticClass:"dashboard-box-card"},[e("div",{attrs:{slot:"header"},slot:"header"},[a.meta&&a.meta.icon?e("i",{class:a.meta.icon}):t._e(),e("span",{staticClass:"dashboard-title"},[t._v(t._s(a.meta.title))])]),t._l(a.children,(function(a){return e("div",{key:a.meta.key},[e("router-link",{attrs:{to:a.path,replace:""}},[e("div",{staticClass:"dashboard-link"},[t._v(t._s(a.meta.title))])])],1)}))],2)})),1)},n=[],r=e("75c0"),i={name:"Dashboard",props:["apiInfo"],methods:{sidebarInfo:function(){return Object(r["c"])(this.$router,this.apiInfo)}}},o=i,c=e("2877"),l=Object(c["a"])(o,s,n,!1,null,null,null);a["default"]=l.exports}}]);